<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问支出记录详情页面');

// 获取记录ID
$id = isset($_GET['id']) ? intval($_GET['id']) : 0;

if ($id <= 0) {
    header('Location: expense.php');
    exit;
}

// 获取支出记录详情
$stmt = $pdo->prepare("
    SELECT fr.*, s.name as store_name 
    FROM finance_records fr
    LEFT JOIN stores s ON fr.store_id = s.id
    WHERE fr.id = ? AND fr.type = 2
");
$stmt->execute([$id]);
$record = $stmt->fetch(PDO::FETCH_ASSOC);

// 如果记录不存在或非支出记录，返回列表页
if (!$record) {
    header('Location: expense.php');
    exit;
}

// 获取创建者信息
$creator_name = '未知';
if (!empty($record['creator_id'])) {
    $stmt = $pdo->prepare("SELECT username FROM sys_users WHERE id = ?");
    $stmt->execute([$record['creator_id']]);
    $creator = $stmt->fetch(PDO::FETCH_ASSOC);
    if ($creator) {
        $creator_name = $creator['username'];
    }
}
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>支出记录详情</h2>
            <div class="breadcrumb">
                <a href="index.php">财务管理</a> &gt;
                <a href="expense.php">支出管理</a> &gt;
                <span>支出记录详情</span>
            </div>
        </div>

        <div class="content">
            <div class="form-container">
                <h3>支出记录 #<?php echo $record['id']; ?></h3>
                <table class="info-table">
                    <tr>
                        <td width="20%">支出类别：</td>
                        <td><?php echo htmlspecialchars($record['category']); ?></td>
                    </tr>
                    <tr>
                        <td>金额：</td>
                        <td>￥<?php echo number_format($record['amount'], 2); ?></td>
                    </tr>
                    <tr>
                        <td>记录日期：</td>
                        <td><?php echo $record['record_date']; ?></td>
                    </tr>
                    <tr>
                        <td>所属门店：</td>
                        <td><?php echo htmlspecialchars($record['store_name']); ?></td>
                    </tr>
                    <?php if (!empty($record['period'])): ?>
                        <tr>
                            <td>结算周期：</td>
                            <td><?php echo $record['period']; ?></td>
                        </tr>
                    <?php endif; ?>
                    <tr>
                        <td>说明：</td>
                        <td><?php echo htmlspecialchars($record['description'] ?: '无'); ?></td>
                    </tr>
                    <tr>
                        <td>创建时间：</td>
                        <td><?php echo $record['create_time']; ?></td>
                    </tr>
                    <tr>
                        <td>创建者：</td>
                        <td><?php echo htmlspecialchars($creator_name); ?></td>
                    </tr>
                </table>

                <div class="form-actions">
                    <a href="expense.php" class="btn btn-secondary">返回列表</a>
                </div>
            </div>
        </div>
    </div>
</body>

</html>