<?php
require_once '../database_config.php';

// 检查用户是否有权限访问此页面
check_permission_or_die('finance');

// 记录访问日志
record_log('访问财务管理页面');

// 获取当月财务统计
$current_month = date('Y-m');
$current_year = date('Y');
$current_month_name = date('Y年m月');

// 获取当月收入总额
$stmt = $pdo->prepare("
    SELECT COALESCE(SUM(amount), 0) as total 
    FROM finance_records 
    WHERE type = 1 AND DATE_FORMAT(record_date, '%Y-%m') = ?
");
$stmt->execute([$current_month]);
$monthly_income = $stmt->fetch(PDO::FETCH_ASSOC)['total'];

// 获取当月支出总额
$stmt = $pdo->prepare("
    SELECT COALESCE(SUM(amount), 0) as total 
    FROM finance_records 
    WHERE type = 2 AND DATE_FORMAT(record_date, '%Y-%m') = ?
");
$stmt->execute([$current_month]);
$monthly_expense = $stmt->fetch(PDO::FETCH_ASSOC)['total'];

// 获取当月利润
$monthly_profit = $monthly_income - $monthly_expense;

// 获取当年收入总额
$stmt = $pdo->prepare("
    SELECT COALESCE(SUM(amount), 0) as total 
    FROM finance_records 
    WHERE type = 1 AND DATE_FORMAT(record_date, '%Y') = ?
");
$stmt->execute([$current_year]);
$yearly_income = $stmt->fetch(PDO::FETCH_ASSOC)['total'];

// 获取当年支出总额
$stmt = $pdo->prepare("
    SELECT COALESCE(SUM(amount), 0) as total 
    FROM finance_records 
    WHERE type = 2 AND DATE_FORMAT(record_date, '%Y') = ?
");
$stmt->execute([$current_year]);
$yearly_expense = $stmt->fetch(PDO::FETCH_ASSOC)['total'];

// 获取当年利润
$yearly_profit = $yearly_income - $yearly_expense;

// 获取各类收入占比
$stmt = $pdo->query("
    SELECT category, COALESCE(SUM(amount), 0) as total 
    FROM finance_records 
    WHERE type = 1 AND DATE_FORMAT(record_date, '%Y-%m') = '$current_month'
    GROUP BY category
    ORDER BY total DESC
");
$income_categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取各类支出占比
$stmt = $pdo->query("
    SELECT category, COALESCE(SUM(amount), 0) as total 
    FROM finance_records 
    WHERE type = 2 AND DATE_FORMAT(record_date, '%Y-%m') = '$current_month'
    GROUP BY category
    ORDER BY total DESC
");
$expense_categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

// 获取待结算供应商数量
$stmt = $pdo->query("
    SELECT COUNT(DISTINCT related_id) as count 
    FROM finance_records 
    WHERE type = 3 AND status = 1
");
$pending_settlements = $stmt->fetch(PDO::FETCH_ASSOC)['count'];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?php echo title; ?></title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>财务管理</h2>
        </div>

        <div class="content">
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3><?php echo $current_month_name; ?>收入</h3>
                    <div class="number">￥<?php echo number_format($monthly_income, 2); ?></div>
                    <div class="desc">年度累计: ￥<?php echo number_format($yearly_income, 2); ?></div>
                </div>

                <div class="dashboard-card">
                    <h3><?php echo $current_month_name; ?>支出</h3>
                    <div class="number">￥<?php echo number_format($monthly_expense, 2); ?></div>
                    <div class="desc">年度累计: ￥<?php echo number_format($yearly_expense, 2); ?></div>
                </div>

                <div class="dashboard-card">
                    <h3><?php echo $current_month_name; ?>利润</h3>
                    <div class="number" style="color: <?php echo $monthly_profit >= 0 ? '#28a745' : '#dc3545'; ?>">
                        ￥<?php echo number_format($monthly_profit, 2); ?>
                    </div>
                    <div class="desc">年度累计: ￥<?php echo number_format($yearly_profit, 2); ?></div>
                </div>

                <div class="dashboard-card">
                    <h3>待结算供应商</h3>
                    <div class="number"><?php echo $pending_settlements; ?></div>
                    <div class="desc">需进行结算对账</div>
                </div>
            </div>

            <h2>功能导航</h2>
            <div class="function-links">
                <a href="income.php" class="function-link">
                    <h3>收入管理</h3>
                </a>
                <a href="expense.php" class="function-link">
                    <h3>支出管理</h3>
                </a>
                <a href="report.php" class="function-link">
                    <h3>财务报表</h3>
                </a>
                <a href="settlement.php" class="function-link">
                    <h3>供应商结算</h3>
                </a>
            </div>

            <h2>收支分析</h2>
            <div class="system-info">
                <h3>当月收入类别分布</h3>
                <table class="info-table">
                    <?php if (count($income_categories) > 0): ?>
                        <?php foreach ($income_categories as $category): ?>
                            <tr>
                                <td width="200"><?php echo $category['category']; ?>:</td>
                                <td>￥<?php echo number_format($category['total'], 2); ?></td>
                                <td width="300">
                                    <div style="background-color: #4CAF50; height: 20px; width: <?php echo ($category['total'] / $monthly_income * 100); ?>%"></div>
                                </td>
                                <td><?php echo number_format($category['total'] / $monthly_income * 100, 2); ?>%</td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="4">暂无收入数据</td>
                        </tr>
                    <?php endif; ?>
                </table>

                <h3 style="margin-top: 20px;">当月支出类别分布</h3>
                <table class="info-table">
                    <?php if (count($expense_categories) > 0): ?>
                        <?php foreach ($expense_categories as $category): ?>
                            <tr>
                                <td width="200"><?php echo $category['category']; ?>:</td>
                                <td>￥<?php echo number_format($category['total'], 2); ?></td>
                                <td width="300">
                                    <div style="background-color: #dc3545; height: 20px; width: <?php echo ($category['total'] / $monthly_expense * 100); ?>%"></div>
                                </td>
                                <td><?php echo number_format($category['total'] / $monthly_expense * 100, 2); ?>%</td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="4">暂无支出数据</td>
                        </tr>
                    <?php endif; ?>
                </table>
            </div>

            <h2>最近财务记录</h2>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>日期</th>
                            <th>类型</th>
                            <th>类别</th>
                            <th>金额</th>
                            <th>说明</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $stmt = $pdo->query("
                            SELECT * FROM finance_records 
                            WHERE type IN (1, 2) 
                            ORDER BY record_date DESC, id DESC
                            LIMIT 10
                        ");
                        $records = $stmt->fetchAll(PDO::FETCH_ASSOC);

                        if (count($records) > 0):
                            foreach ($records as $record):
                                $type_text = $record['type'] == 1 ? '收入' : '支出';
                                $type_class = $record['type'] == 1 ? 'status-active' : 'status-inactive';
                        ?>
                                <tr>
                                    <td><?php echo $record['id']; ?></td>
                                    <td><?php echo $record['record_date']; ?></td>
                                    <td class="<?php echo $type_class; ?>"><?php echo $type_text; ?></td>
                                    <td><?php echo $record['category']; ?></td>
                                    <td>￥<?php echo number_format($record['amount'], 2); ?></td>
                                    <td><?php echo $record['description']; ?></td>
                                </tr>
                            <?php
                            endforeach;
                        else:
                            ?>
                            <tr>
                                <td colspan="6" class="text-center">暂无财务记录</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>