<?php
// member/index.php - 会员管理首页
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('member.view');

// 获取会员总数
$stmt = $pdo->query("SELECT COUNT(*) as total FROM members");
$memberCount = $stmt->fetch()['total'];

// 获取今日新增会员
$today = date('Y-m-d');
$stmt = $pdo->prepare("SELECT COUNT(*) as total FROM members WHERE DATE(create_time) = ?");
$stmt->execute([$today]);
$todayNewCount = $stmt->fetch()['total'];

// 获取总储值金额
$stmt = $pdo->query("SELECT SUM(balance) as total FROM members");
$totalBalance = $stmt->fetch()['total'] ?: 0;

// 获取总积分
$stmt = $pdo->query("SELECT SUM(points) as total FROM members");
$totalPoints = $stmt->fetch()['total'] ?: 0;

// 获取会员等级统计
$stmt = $pdo->query("SELECT l.level_name, COUNT(m.id) as count 
                     FROM member_levels l 
                     LEFT JOIN members m ON l.id = m.level_id 
                     GROUP BY l.id 
                     ORDER BY l.min_points");
$levelStats = $stmt->fetchAll();

// 获取最近加入的会员
$stmt = $pdo->query("SELECT m.*, l.level_name 
                     FROM members m 
                     LEFT JOIN member_levels l ON m.level_id = l.id 
                     ORDER BY m.create_time DESC LIMIT 5");
$recentMembers = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>会员管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>会员管理</h2>
        </div>

        <div class="content">
            <!-- 数据概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>会员总数</h3>
                    <div class="number"><?php echo $memberCount; ?></div>
                    <div class="desc">系统中的会员数量</div>
                </div>
                <div class="dashboard-card">
                    <h3>今日新增</h3>
                    <div class="number"><?php echo $todayNewCount; ?></div>
                    <div class="desc">今日新增会员数量</div>
                </div>
                <div class="dashboard-card">
                    <h3>总储值金额</h3>
                    <div class="number">￥<?php echo number_format($totalBalance, 2); ?></div>
                    <div class="desc">所有会员的储值余额</div>
                </div>
                <div class="dashboard-card">
                    <h3>总积分</h3>
                    <div class="number"><?php echo number_format($totalPoints); ?></div>
                    <div class="desc">所有会员的积分总和</div>
                </div>
            </div>

            <!-- 功能链接 -->
            <div class="function-links">
                <a href="info.php" class="function-link">
                    <h3>会员信息管理</h3>
                </a>
                <a href="points.php" class="function-link">
                    <h3>会员积分管理</h3>
                </a>
                <a href="recharge.php" class="function-link">
                    <h3>会员充值管理</h3>
                </a>
            </div>

            <!-- 会员等级分布 -->
            <h3>会员等级分布</h3>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>会员等级</th>
                            <th>所需积分</th>
                            <th>会员数量</th>
                            <th>折扣率</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($levelStats as $level): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($level['level_name']); ?></td>
                                <td>
                                    <?php
                                    $stmt = $pdo->prepare("SELECT min_points FROM member_levels WHERE level_name = ?");
                                    $stmt->execute([$level['level_name']]);
                                    $minPoints = $stmt->fetch()['min_points'];
                                    echo $minPoints;
                                    ?>
                                </td>
                                <td><?php echo $level['count']; ?></td>
                                <td>
                                    <?php
                                    $stmt = $pdo->prepare("SELECT discount FROM member_levels WHERE level_name = ?");
                                    $stmt->execute([$level['level_name']]);
                                    $discount = $stmt->fetch()['discount'];
                                    echo $discount * 10 . ' 折';
                                    ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($levelStats)): ?>
                            <tr>
                                <td colspan="4" class="text-center">暂无会员等级数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- 最近加入的会员 -->
            <h3>最近加入的会员</h3>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>姓名</th>
                            <th>手机号码</th>
                            <th>会员等级</th>
                            <th>积分</th>
                            <th>储值余额</th>
                            <th>注册时间</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recentMembers as $member): ?>
                            <tr>
                                <td><?php echo $member['id']; ?></td>
                                <td><?php echo htmlspecialchars($member['name']); ?></td>
                                <td><?php echo htmlspecialchars($member['phone']); ?></td>
                                <td><?php echo htmlspecialchars($member['level_name']); ?></td>
                                <td><?php echo $member['points']; ?></td>
                                <td>￥<?php echo number_format($member['balance'], 2); ?></td>
                                <td><?php echo $member['create_time']; ?></td>
                                <td>
                                    <a href="info.php?action=view&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                    <a href="info.php?action=edit&id=<?php echo $member['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($recentMembers)): ?>
                            <tr>
                                <td colspan="8" class="text-center">暂无会员数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>