<?php
// store/index.php - 门店管理首页
session_start();
require_once '../database_config.php';

// 检查用户是否具有访问权限
check_permission_or_die('store.view');

// 获取门店总数
$stmt = $pdo->query("SELECT COUNT(*) as total FROM stores");
$storeCount = $stmt->fetch()['total'];

// 获取员工总数
$stmt = $pdo->query("SELECT COUNT(*) as total FROM employees");
$employeeCount = $stmt->fetch()['total'];

// 获取总销售额
$stmt = $pdo->query("SELECT SUM(sales_amount) as total FROM store_statistics");
$totalSales = $stmt->fetch()['total'] ?: 0;

// 获取门店列表（最新的5个）
$stmt = $pdo->query("SELECT * FROM stores ORDER BY id DESC LIMIT 5");
$recentStores = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>门店管理 - FloraEase</title>
    <link rel="stylesheet" href="../style.css">
</head>

<body>
    <div class="container">
        <div class="header-local">
            <h2>门店管理</h2>

        </div>

        <div class="content">
            <!-- 数据概览 -->
            <div class="dashboard">
                <div class="dashboard-card">
                    <h3>门店总数</h3>
                    <div class="number"><?php echo $storeCount; ?></div>
                    <div class="desc">当前系统中的门店数量</div>
                </div>
                <div class="dashboard-card">
                    <h3>员工总数</h3>
                    <div class="number"><?php echo $employeeCount; ?></div>
                    <div class="desc">所有门店的员工总数</div>
                </div>
                <div class="dashboard-card">
                    <h3>总销售额</h3>
                    <div class="number">￥<?php echo number_format($totalSales, 2); ?></div>
                    <div class="desc">所有门店的累计销售额</div>
                </div>
            </div>

            <!-- 功能链接 -->
            <div class="function-links">
                <a href="info.php" class="function-link">
                    <h3>门店信息管理</h3>
                </a>
                <a href="employee.php" class="function-link">
                    <h3>员工管理</h3>
                </a>
                <a href="stat.php" class="function-link">
                    <h3>营业统计</h3>
                </a>
            </div>

            <!-- 最近添加的门店 -->
            <h3>最近添加的门店</h3>
            <div class="table-container">
                <table class="data-table">
                    <thead>
                        <tr>
                            <th>ID</th>
                            <th>门店名称</th>
                            <th>所属区域</th>
                            <th>联系人</th>
                            <th>电话</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($recentStores as $store): ?>
                            <tr>
                                <td><?php echo $store['id']; ?></td>
                                <td><?php echo htmlspecialchars($store['name']); ?></td>
                                <td><?php echo htmlspecialchars($store['area']); ?></td>
                                <td><?php echo htmlspecialchars($store['contact_person']); ?></td>
                                <td><?php echo htmlspecialchars($store['phone']); ?></td>
                                <td>
                                    <?php if ($store['status'] == 1): ?>
                                        <span class="status-active">营业中</span>
                                    <?php else: ?>
                                        <span class="status-inactive">已关闭</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="info.php?action=edit&id=<?php echo $store['id']; ?>" class="btn btn-sm btn-primary">编辑</a>
                                    <a href="info.php?action=view&id=<?php echo $store['id']; ?>" class="btn btn-sm btn-secondary">查看</a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                        <?php if (empty($recentStores)): ?>
                            <tr>
                                <td colspan="7" class="text-center">暂无门店数据</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        </div>
    </div>
</body>

</html>